// Generated by dts-bundle v0.7.3
// Dependencies for this module:
//   ../@grapecity/dataviews.common
//   ../react
//   ../prop-types

declare module '@grapecity/dataviews.react' {
    /**
        * @module React
        * @preferred
        *
        * This module provides component to integrate {@link DataView} control to React applications.
        */
    import { getControlByElement } from '@grapecity/dataviews.common';
    import DataView from '@grapecity/dataviews.react/react';
    export { DataView as ReactComponent, 
    /**
        * Gets the instance of DataView which is hosted to the specified node
        *
        * @param node an HTML element which is used to host the [[DataView]] instance
        * @returns a [[DataView]] instance
        */
    getControlByElement, };
    export default DataView;
}

declare module '@grapecity/dataviews.react/react' {
    /** @jsx React.createElement */
    import React, { CSSProperties } from 'react';
    import PropTypes from 'prop-types';
    import { EventHandler, getControlByElement, IBeforeLoadRangeEventArgs, IColumn, IColumnChangedEventArgs, IColumnReorderEventArgs, IRowReorderEventArgs, IEditingEventArgs, IFocusChangedEventArgs, IGrid, IGroupingEventArgs, ILayoutEngine, IRowClickEventArgs, ISelectionChangedEventArgs } from '@grapecity/dataviews.common';
    /**
        * Defines properties of [[DataViewComponent]]
        */
    interface IDataViewProps {
            /**
                * Specifies ID of the DOM container
                */
            id?: string;
            /**
                * Specifies CSS class name of the DOM container
                */
            className?: string;
            /**
                * Specifies width of the DOM container
                */
            width?: string | number;
            /**
                * Specifies height of the DOM container
                */
            height?: string | number;
            /**
                * Specifies other styles of the DOM container
                */
            style?: CSSProperties;
            /**
                * Specifies other props of the DOM container
                */
            containerProps?: React.HTMLAttributes<HTMLDivElement>;
            /**
                * Specifies an array of objects for the grid model or a dataSource object
                */
            data: any;
            /**
                * Specifies an array of column definitions to initialize the grid
                */
            cols?: IColumn[];
            /**
                * Specifies a JSON object used to deserialize the grid from
                */
            config?: any;
            /**
                * Specifies layout strategy. Default value is instance of [[GridLayout]] with default options
                */
            layout?: ILayoutEngine;
            /**
                * Specifies options of layout strategy and other common options like filtering/sorting/grouping.
                */
            options?: any;
            /**
                * Specifies options of grouping strategy.
                */
            groupingOptions?: any;
            /**
                * Auto focus DOM container on mount.
                */
            autoFocus?: boolean;
            /**
                * Callback on each creation of underlying DataView component.
                */
            onCreate?(grid: IGrid): void;
            /**
                * This event occurs when the user changes the selection using UI actions.
                */
            onSelectionChanged?: EventHandler<ISelectionChangedEventArgs>;
            /**
                * This event occurs when the focused row is changed. The event fires on [[GridLayout]] or [[HorizontalLayout]]
                */
            onFocusChanged?: EventHandler<IFocusChangedEventArgs>;
            /**
                * This event occurs when the user updates groups with UI actions. The event is fired before the actual update happens
                */
            onGrouping?: EventHandler<IGroupingEventArgs>;
            /**
                * This event occurs when clicking the row
                */
            onRowClick?: EventHandler<IRowClickEventArgs>;
            /**
                * This event occurs when double-clicking the row
                */
            onRowDbClick?: EventHandler<IRowClickEventArgs>;
            /**
                * This event occurs when the user starts dragging the column and before dropping the column in the column header
                */
            onColumnReorder?: EventHandler<IColumnReorderEventArgs>;
            /**
                * This event occurs when the user starts dragging the row and before inserting the row at new position
                */
            onRowReorder?: EventHandler<IRowReorderEventArgs>;
            /**
                * This event occurs when the user changes the column visibility, pinned option, or column width, or expands or collapses the column group from UI
                */
            onColumnChanged?: EventHandler<IColumnChangedEventArgs>;
            /**
                * This event occurs before editing, once editing has started, before editing has ended, or editing has stopped
                */
            onEditing?: EventHandler<IEditingEventArgs>;
            /**
                * This event occurs before loading next data range.
                */
            onBeforeLoadRange?: EventHandler<IBeforeLoadRangeEventArgs>;
    }
    /**
        * Implements React integration for {@link DataView} control
        *
        * See examples:
        * - {@sample Features/Basics/Introduction/react Basic Data Grid}
        * - {@sample DataViews/Calendar/Calendar/react Calendar Layout}
        * - {@sample DataViews/Card/CardLayoutEngine/react Card Layout}
        * - {@sample DataViews/Trellis/TrellisWithGridLayout/react Trellis Layout}
        * - {@sample DataViews/Masonry/MasonryLayout/react Masonry Layout}
        * - {@sample DataViews/Timeline/TimelineGrouping/react Timeline Grouping}
        */
    class DataViewComponent extends React.Component<IDataViewProps> {
            /**
                * Gets the instance of DataView which is hosted to the specified node
                *
                * @param node an HTML element which is used to host the [[DataView]] instance
                * @returns a [[DataView]] instance
                */
            static getControlByElement: typeof getControlByElement;
            static propTypes: {
                    id: PropTypes.Requireable<string>;
                    className: PropTypes.Requireable<string>;
                    width: PropTypes.Requireable<string | number>;
                    height: PropTypes.Requireable<string | number>;
                    style: PropTypes.Requireable<object>;
                    containerProps: PropTypes.Requireable<object>;
                    data: PropTypes.Validator<any>;
                    cols: PropTypes.Requireable<unknown[]>;
                    config: PropTypes.Requireable<object>;
                    layout: PropTypes.Requireable<object>;
                    onSelectionChanged: PropTypes.Requireable<(...args: any[]) => any>;
                    onFocusChanged: PropTypes.Requireable<(...args: any[]) => any>;
                    onGrouping: PropTypes.Requireable<(...args: any[]) => any>;
                    onRowClick: PropTypes.Requireable<(...args: any[]) => any>;
                    onRowDbClick: PropTypes.Requireable<(...args: any[]) => any>;
                    onColumnReorder: PropTypes.Requireable<(...args: any[]) => any>;
                    onColumnChanged: PropTypes.Requireable<(...args: any[]) => any>;
                    onEditing: PropTypes.Requireable<(...args: any[]) => any>;
            };
            protected container: HTMLElement;
            protected dataView: IGrid;
            componentDidMount(): void;
            componentWillUnmount(): void;
            componentDidUpdate(prevProps: Readonly<IDataViewProps>, prevState: Readonly<{}>, snapshot?: any): void;
            containerRef: (container: HTMLElement) => void;
            render(): any;
            makeDefaultLayout(): ILayoutEngine;
            createView(): void;
            applyOptions(forceInvalidate: boolean): void;
            destroyView(): void;
            registerHandlers(): void;
            unregisterHandlers(): void;
            updateHandlers(prevProps: Readonly<IDataViewProps>): void;
    }
    export default DataViewComponent;
}

